function [ index ] = performance ( score, outlier )
% Calculate performance indices as presented here:
%           On the Evaluation of Unsupervised Outlier Detection: Measures, Datasets, and an Empirical Study
%           by G. O. Campos, A. Zimek, J. Sander, R. J. G. B. Campello, B. Micenková, E. Schubert, I. Assent and M. E. Houle
%           Data Mining and Knowledge Discovery 30(4): 891-927, 2016, DOI: 10.1007/s10618-015-0444-8
%           http://www.dbs.ifi.lmu.de/research/outlier-evaluation/DAMI/
% FIV, Dec 2017

card_O=sum(outlier);
N=length(outlier);
a(:,1)=score;
a(:,2)=outlier;
b=sortrows(a,-1);

% P@n
n=card_O;
patn=sum(b(1:n,2))/n;

% Adjusted P@n
adj_patn=(patn-card_O/N)/(1-card_O/N);

% AP
for i=1:card_O
    ap(i)=sum(b(1:i,2))/i;
end
AP=sum(ap)/card_O;

% Adjusted AP
adj_AP=(AP-card_O/N)/(1-card_O/N);

% ROC/AUC
[X,Y,T,AUC] = perfcurve(outlier,score,1);

%F1
for i=1:N
    tp=sum(b(1:i,2));
    fp=i-tp;
    fn=card_O-tp;
    f1(i)=2*tp/(2*tp+fp+fn);
end
F1max=max(f1);

% Adjusted MF1
adj_MF1=(F1max-card_O/N)/(1-card_O/N);

index.P_at_n=patn;
index.adjP_at_n=adj_patn;
index.AP=AP;
index.adjAP=adj_AP;
index.ROC_AUC=AUC;
index.MaxF1=F1max;
index.adj_MF1=adj_MF1;
end
