function perf = sdo_synthetic_tests ( seed, runs )
% SDO_synthetic_TESTS uses MDCGEN to generate datasets with outliers and ranks
% them with SDO.
%
% It requires MDCGEN, you can download it from:
% https://github.com/CN-TU/mdcgen-matlab
% It requires SDO, you can download it from:
% https://github.com/CN-TU/sdo-matlab
%
% INPUTS:
% seed, random seed
% runs, number of datasets to generate
%
% OUTPUTS:
% perf, 
%   .ind,   contains the performance indices (columns) for every test (rows)
%           the meaning of the indices can be consulted in:
%           On the Evaluation of Unsupervised Outlier Detection: Measures, Datasets, and an Empirical Study
%           by G. O. Campos, A. Zimek, J. Sander, R. J. G. B. Campello, B. Micenková, E. Schubert, I. Assent and M. E. Houle
%           Data Mining and Knowledge Discovery 30(4): 891-927, 2016, DOI: 10.1007/s10618-015-0444-8
%           http://www.dbs.ifi.lmu.de/research/outlier-evaluation/DAMI/
%   .pam,   contains the SDO parameters (columns) for every test (rows)
%           1st col, number of total samples
%           2nd col, number of inliers
%           3rd col, number of outliers
%           4th col, number of features
%           5th col, number of total observers
%           6th col, closest observers (SDO parameter)
%           7th col, observation threshold (SDO parameter)
%           8th col, quantile threshold for 'q' calculation
% FIV, Dec 2017

if exist('seed')==0, seed=100;end
if exist('runs')==0, runs=100; end

% p: dataset fixed parameters
p.k=2;
p.N=2;
p.M=1000;
p.d=0;
p.dflag=[1,1,1,1,0,0];
p.mv=0;
p.alphaN=2;
p.corr=0;
p.cp=0.1;
p.scale=1;
p.rot=1;
p.Nnoise=0;

rng(seed); %control random number generation

% dataset: variable parameters for testing
M=1000+floor(2901*rand(runs,1));
k=2+round(5*rand(runs,1));
N=2+round(50*rand(runs,1));
cp=0.02+0.08*rand(runs,1);
out=2+floor(bsxfun(@times,M,0.1*rand(runs,1)));
alpha=1+floor(2*rand(runs,1));

for i=1:runs  
    p.M=M(i); 
    p.N=N(i);
    p.k=k(i); 
    p.cp=cp(i); p.out=out(i); p.sd=seed+i; p.alpha=alpha(i); 
    fprintf('%d:g',i);
    [dataset] = mdcgen( p );
    data=dataset.MN;
    class=dataset.label;
    outlier=dataset.label==0;
 
    ps.sd=0;
    ps.hbs=0;
    
    fprintf('o');
    [y,r,po] = sdo(data, ps);
    fprintf('i\n');
    [ index ] = performance ( y, outlier );
    ind(i,:)=[index.P_at_n, index.adjP_at_n, index.AP, index.adjAP, index.MaxF1, index.adj_MF1, index.ROC_AUC];
    pam(i,:)=[po.m, p.M, sum(outlier), po.n, po.k, po.x, po.q, po.qv];
end

perf.ind=ind;
perf.pam=pam;
end


